==> wiredash-0.2.0.tar.gz: lib/src/common/translation/l10n/messages_nl.dart <==
import 'package:wiredash/wiredash.dart';

class WiredashLocalizedTranslations extends WiredashTranslations {
  const WiredashLocalizedTranslations() : super();
  @override
  String get captureSaveScreenshot => "Schermafbeelding bewaren";
  @override
  String get captureSkip => "Schermafbeelding overslaan";
  @override
  String get captureSpotlightNavigateMsg =>
      "Navigeer naar het scherm dat je wenst vast te leggen";
  @override
  String get captureSpotlightNavigateTitle => "navigeer";
  @override
  String get captureSpotlightScreenCapturedMsg =>
      "Schermafbeelding vastgelegd! Teken gerust op de schermafbeelding om zaken te markeren.";
  @override
  String get captureSpotlightScreenCapturedTitle => "teken";
  @override
  String get captureTakeScreenshot => "Neem schermafbeelding";
  @override
  String get feedbackBack => "Ga terug";
  @override
  String get feedbackCancel => "Annuleren";
  @override
  String get feedbackModeBugMsg =>
      "Laat het ons weten zodat we dit kunnen oplossen.";
  @override
  String get feedbackModeBugTitle => "Meld een probleem";
  @override
  String get feedbackModeImprovementMsg =>
      "Heb je een goed idee om onze app beter te maken? Laat het ons weten!";
  @override
  String get feedbackModeImprovementTitle => "Verzoek om een functie";
  @override
  String get feedbackModePraiseMsg =>
      "Laat ons weten wat je leuk vindt aan onze app, misschien kunnen we hem zelfs beter maken!";
  @override
  String get feedbackModePraiseTitle => "Stuur een applaus";
  @override
  String get feedbackSave => "Bewaren";
  @override
  String get feedbackSend => "Verstuur feedback";
  @override
  String get feedbackStateEmailMsg =>
      "Als je op de hoogte wenst gehouden te worden, geef je email hier dan in.";
  @override
  String get feedbackStateEmailTitle => "Blijft op de hoogte 👇";
  @override
  String get feedbackStateFeedbackMsg =>
      "We luisteren. Geef ons zoveel mogelijk info om je te kunnen helpen.";
  @override
  String get feedbackStateIntroMsg =>
      "We kunnen niet wachten op je feedback over onze app. Wat wil je doen?";
  @override
  String get feedbackStateIntroTitle => "Hey hallo 👋";
  @override
  String get feedbackStateSuccessCloseMsg => "Bedankt voor je feedback!";
  @override
  String get feedbackStateSuccessCloseTitle => "Sluit dit venster";
  @override
  String get feedbackStateSuccessMsg =>
      "Dat was het. Hartelijk dank om ons te helpen de app beter te maken!";
  @override
  String get feedbackStateSuccessTitle => "Bedankt ✌️";
  @override
  String get inputHintEmail => "Jouw email";
  @override
  String get inputHintFeedback => "Jouw feedback";
  @override
  String get validationHintEmail =>
      "Gelieve een correcte email in te geven, of laat het veld leeg.";
  @override
  String get validationHintFeedbackEmpty => "Gelieve je feedback te geven.";
  @override
  String get validationHintFeedbackLength => "Jouw feedback is te lang.";
  @override
  String get feedbackStateFeedbackTitle => "Jouw feedback ✌️";
}

==> wiredash-0.3.0.tar.gz: lib/src/common/translation/l10n/messages_nl.dart <==
import 'package:wiredash/wiredash.dart';

class WiredashLocalizedTranslations extends WiredashTranslations {
  const WiredashLocalizedTranslations() : super();
  @override
  String get captureSaveScreenshot => "Schermafbeelding bewaren";
  @override
  String get captureSkip => "Schermafbeelding overslaan";
  @override
  String get captureSpotlightNavigateMsg =>
      "Navigeer naar het scherm dat je wenst vast te leggen";
  @override
  String get captureSpotlightNavigateTitle => "navigeer";
  @override
  String get captureSpotlightScreenCapturedMsg =>
      "Schermafbeelding vastgelegd! Teken gerust op de schermafbeelding om zaken te markeren.";
  @override
  String get captureSpotlightScreenCapturedTitle => "teken";
  @override
  String get captureTakeScreenshot => "Neem schermafbeelding";
  @override
  String get feedbackBack => "Ga terug";
  @override
  String get feedbackCancel => "Annuleren";
  @override
  String get feedbackModeBugMsg =>
      "Laat het ons weten zodat we dit kunnen oplossen.";
  @override
  String get feedbackModeBugTitle => "Meld een probleem";
  @override
  String get feedbackModeImprovementMsg =>
      "Heb je een goed idee om onze app beter te maken? Laat het ons weten!";
  @override
  String get feedbackModeImprovementTitle => "Verzoek om een functie";
  @override
  String get feedbackModePraiseMsg =>
      "Laat ons weten wat je leuk vindt aan onze app, misschien kunnen we hem zelfs beter maken!";
  @override
  String get feedbackModePraiseTitle => "Stuur een applaus";
  @override
  String get feedbackSave => "Opslaan";
  @override
  String get feedbackSend => "Verstuur feedback";
  @override
  String get feedbackStateEmailMsg =>
      "Als je op de hoogte wenst gehouden te worden, geef je email hier dan in.";
  @override
  String get feedbackStateEmailTitle => "Blijft op de hoogte 👇";
  @override
  String get feedbackStateFeedbackMsg =>
      "We luisteren. Geef ons zoveel mogelijk info om je te kunnen helpen.";
  @override
  String get feedbackStateIntroMsg =>
      "We kunnen niet wachten op je feedback over onze app. Wat wil je doen?";
  @override
  String get feedbackStateIntroTitle => "Hey hallo 👋";
  @override
  String get feedbackStateSuccessCloseMsg => "Bedankt voor je feedback!";
  @override
  String get feedbackStateSuccessCloseTitle => "Sluit dit venster";
  @override
  String get feedbackStateSuccessMsg =>
      "Dat was het. Hartelijk dank om ons te helpen de app beter te maken!";
  @override
  String get feedbackStateSuccessTitle => "Bedankt ✌️";
  @override
  String get inputHintEmail => "Jouw email";
  @override
  String get inputHintFeedback => "Jouw feedback";
  @override
  String get validationHintEmail =>
      "Gelieve een correcte email in te geven, of laat het veld leeg.";
  @override
  String get validationHintFeedbackEmpty => "Gelieve je feedback te geven.";
  @override
  String get validationHintFeedbackLength => "Jouw feedback is te lang.";
  @override
  String get feedbackStateFeedbackTitle => "Jouw feedback ✌️";
}
